@@ -126,8 +126,7 @@ class NextJobHandler(BaseHandler):
             page_size=page_size
         )
 
-        #review_count = self.girl.get('next_jobs_count')
-        review_count = 0
+        review_count = self.girl.get('next_jobs_count')
 
         result = {'reviewCount': review_count}
         pages = []
